import React, { useState, useEffect} from 'react';
import { Row, Col, Tree, Card, Input, Tooltip} from 'antd';
import { 
  FileAddTwoTone,
  EditTwoTone,
  DeleteTwoTone,
} from '@ant-design/icons';
import { PageContainer, GridContent } from '@ant-design/pro-layout';
import { getOUTree, getWebModuleTree} from '@/services/userCenter/siteManage/api';
import ListCard from '@/pages/orgnazation/ListCard';
import styles from '@/pages/userCenter/siteManage/SiteManage.less';
import AddModal from './AddModal'
import DelModal from './DelModal'
import EditModal from './EditModal'
const { Search } = Input;
const placeholder = '请输入人员姓名'
const SiteManage = ()=>{
  const [ treeData, setTreeData ] = useState([])
  const [ searchWord, setSearchWord] = useState( '')
  const [ ouid, setOuid ] = useState('')
  const [saveTreeId, setSaveTreeId] = useState('')//保存点击回调的id
  const [modalVisible, setModalVisible] = useState(false) //新增弹窗
  const [flag, setFlag] = useState(1)
  const [ stationId, setStationId] = useState('') //选择的站点
  const [ stationObj, setStationObj] = useState({}) //选择的站点
  const [delVisible, setDelVisible] = useState(false) //删除弹窗
  const [editVisible, setEditVisible] = useState(false) //修改弹窗
  const now = new Date().getTime()
  //点击树的回调
  const handleTreeSelect = (e) =>{
    console.log(e)
    let id = e[0]
    if(id){
      setSaveTreeId(id)
      setOuid(id)
    }else{
      setOuid(saveTreeId)
    }
  }
  useEffect(()=>{
    getWebModuleTree({
      userMode:"super",
      select:'',
      _version:9999,
      _dc:now ,
      node:-2
    }).then(res =>{
      let arr =[]
      if(res){
        arr.push( res.find(item =>{
          return item.id==='Web4StationRoot'
        }))
        console.log(arr,'arr')
      }
      let arr2 = transTree(arr)
      setTreeData(arr2)
    }).catch(err =>{
      console.error(err)
    })
    // getOUTree().then(res =>{   
    //  let arr = transTree(res)
    //   setTreeData(arr)
    // }).catch(err =>{
    //   console.error(err)
    // })
  },[flag])
  const Title = (props) =>{
    const { text } = props
   return (
     <div className={styles.treeTitle}>
        {text}
        <div className={styles.titleBox}>
          <Tooltip title='新增站点'><FileAddTwoTone onClick={()=>{ handleAdd(props)}} /></Tooltip>
          <Tooltip title='编辑站点'><EditTwoTone onClick={()=>{ handleEdit(props)}} /></Tooltip>
          <Tooltip title='删除站点'><DeleteTwoTone onClick={()=>{ handleDel(props)}}/></Tooltip>
        </div>
     </div>
   )
  }
  const handleAdd = (e) =>{
    console.log(e)
    setModalVisible(true)
  }
  //站点删除
  const handleDel = (e) =>{
    setStationId(e.stationID)
    setDelVisible(true)
  }
  //编辑站点
  const handleEdit =(e) =>{
    setStationObj(e)
    setEditVisible(true)
  }
  //树形数据转换
  const transTree = (val) =>{
    let arr = val
   return arr.map( item =>{
      item.title = Title(item) || item.text
      item.key = item.id
      // item.icon = (<img src={user_green} style={{marginBottom:'2px'}}/>)
      let obj = {}
      if(Array.isArray(item.children) && item.children.length > 0){
        transTree(item.children)
        return obj = item
      }else{
        return item
      }
    })
  }
  //获取搜索框的值
  const handleSearch = (value) =>{
    setSearchWord(value)
  }
  const confirmModal = (e) =>{
    setModalVisible(false)
    setFlag(flag+1)
  }
  const delModal = ()=>{
    setDelVisible(false)
    setFlag(flag+1)
  }
  const editModal = () =>{
    setEditVisible(false)
    setFlag(flag+1)
  }
  return (
    <PageContainer>
      <GridContent>
        <Row gutter={12}>
          <Col lg={6} md={24}>
            <Card className={ styles.cardBox}>
              <Tree 
                showLine={{showLeafIcon:false}}
                showIcon
                onSelect={(e)=> handleTreeSelect(e)}
                treeData={treeData}
              />
              <AddModal 
                visible = {modalVisible}
                onCancel={() => setModalVisible(false)}
                confirmModal={confirmModal}              
              />
              <DelModal 
                visible={delVisible} 
                stationId={stationId} 
                onCancel={() => setDelVisible(false)} 
                confirmModal = { delModal}/>
              <EditModal
                visible={editVisible} 
                stationObj={stationObj}
                onCancel={() => setEditVisible(false)} 
                confirmModal = { editModal}
              />
            </Card>
          </Col>
          <Col lg={18} md={24}>
            <Card className={ styles.cardBox}>
              <Row  align='middle'>
                <Col span={1}>搜索</Col>
                <Col span={ 8}>
                  <Search 
                    allowClear
                    placeholder = {placeholder}
                    onSearch = { handleSearch}
                    enterButton
                  />
                </Col>
              </Row>
              { ouid && <ListCard ouid={ouid} searchWord = { searchWord }></ListCard>}
            </Card>
          </Col>
        </Row>
      </GridContent>
    </PageContainer>
  )
}

export default SiteManage
